# P.E.T
A python tool to edit image geolocation data.

## Installation

Run pip install.

```shell
pip install git+https://github.com/ahoodatheguy/P.E.T
```

## Usage
Just run `pet gps` followed by the path of an image in quotes.

![](https://github.com/ahoodatheguy/P.E.T/blob/main/docs/media/demo.gif)

# Help menu
You can run `pet --help` to get a list of commands.
